[vlc-devel] commit: Use stream_t path instead of access_t one. (Laurent Aimar )

git version control git at videolan.org
Sun Jan 25 18:01:19 CET 2009


vlc | branch: master | Laurent Aimar <fenrir at videolan.org> | Sun Jan 25 17:29:37 2009 +0100| [0b3f034fd5e3802d459caca8b11ee48bf1b29b7a] | committer: Laurent Aimar 

Use stream_t path instead of access_t one.

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=0b3f034fd5e3802d459caca8b11ee48bf1b29b7a
---

 src/input/input.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/input/input.c b/src/input/input.c
index a08542e..53b6caf 100644
--- a/src/input/input.c
+++ b/src/input/input.c
@@ -2522,13 +2522,13 @@ static int InputSourceInit( input_thread_t *p_input,
         }
 
         {
             /* Take access redirections into account */
             char *psz_real_path;
             char *psz_buf = NULL;
-            if( in->p_access->psz_path )
+            if( in->p_stream->psz_path )
             {
                 const char *psz_a, *psz_d;
-                psz_buf = strdup( in->p_access->psz_path );
+                psz_buf = strdup( in->p_stream->psz_path );
                 input_SplitMRL( &psz_a, &psz_d, &psz_real_path, psz_buf );
             }
             else
@@ -2522,13 +2522,13 @@ static int InputSourceInit( input_thread_t *p_input,
 
         {
-            /* Take access redirections into account */
+            /* Take access/stream redirections into account */
             char *psz_real_path;
             char *psz_buf = NULL;




More information about the vlc-devel mailing list